@@ -1092,7 +1092,7 @@ class Client(commandServer, encrypt, Desktop):
         smbClientCmd = checkUtils('/usr/bin/smbclient')
         p = process(smbClientCmd, "-N", "//{}/remote".format(domain),
                     stderr=STDOUT)
-        if "NT_STATUS_ACCESS_DENIED" p.read():
+        if "NT_STATUS_ACCESS_DENIED" in p.read():
             return True
         else:
             self.printERROR(_("Samba server not found in %s") % domain)
